<template>
    <section class="suggested_product">
        <div class="container" v-if="products.length > 0">
            <div class="row" :key="componentKey">
                <div class="col-sm-12 col-md-12">
                    <h2 class="text-center">Related products</h2>
                    <div class="product_listing">
                        <div class="row">
                            <div class="col-12 col-sm-6 col-md-4 col-lg-4  col-xl-3" v-for="(product, i) in products"
                                :key="i">
                                <div class="product_item"> <a :href="buildProductUrl(product)">
                                        <div class="product_img"><img v-if="product.file_upload.length > 0"
                                                :src="`${options.storage_root}/` + product.file_upload[0].upload.uploaded_path"
                                                :title="(product.file_upload[0].title != null) ? product.file_upload[0].title : product.name"
                                                :alt="(product.file_upload[0].alt_text != null) ? product.file_upload[0].alt_text : product.name">
                                            <img :alt="product.name" v-else src="/images/no-img.png">
                                        </div>
                                        <h2>{{ product.name }}</h2>

                                        <div class="pricings" v-if="!auth_check">
                                            <ul>
                                                <li v-for="(pricing, ind) in product.pricings" :key="ind">Available <span
                                                        v-if="pricing.rent_term != null">{{ pricing.rent_term.name
                                                        }}</span><span v-else>{{ pricing.custom_rent_term }}</span> <span
                                                        v-if="pricing.rent_period != null"> {{ pricing.rent_period.name
                                                        }}</span></li>
                                            </ul>
                                        </div>
                                        <span class="font-weight-bold pl-4" v-if="product.selected_pricing != null">Price :
                                            ${{ (product.selected_pricing.price*1).toFixed(2) }} </span>
                                        <div class="view_btn_mobile">View Pricing</div>
                                    </a>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
</template>
<script>
import { cloneDeep } from 'lodash';
import options from '~/assets/options';
export default {
    props: ['products'],
    data() {
        return {
            options: options,
            componentKey: 1,
            location_name: "",
            auth_check  : Boolean(this.$store.state.front_end_data.auth_check),
            domain: this.$store.state.front_end_data.domain,
        }
    },
    mounted() {
        this.location_name = this.$store.state.front_end_data.location_name;
        this.$store.watch(() => this.$store.state.front_end_data, async () => {
            this.location_name = this.$store.state.front_end_data.location_name;
        });
    },
    methods: {
        buildProductUrl(product) {
            let parent_category = (product.default_category.parent_category != null) ? product.default_category.parent_category.link_rewrite + '/' : "";
            let route = '/' + this.location_name + '/' + parent_category + product.default_category.link_rewrite + '/' + product.link_rewrite;
            return route;
        },
        viewDetail(product) {
            if (!this.$store.state.ssr_mode) {
                window.open('/' + this.location_name + '/' + product.default_category.link_rewrite + '/' + product.link_rewrite, '_self');
            }
        },
        getPrice(product) {
            let price_list = [];
            for (var i in product.pricings) {
                price_list.push(product.pricings[i]);
            }
            let pricings = price_list.map(x => ({ ...x, name: `${(x.rent_term != null) ? x.rent_term.name : x.custom_rent_term} ${(x.rent_period != null) ? x.rent_period.name : ""}` }));
            return pricings;
        },
    }
}
</script>